# qwikcrud

[![PyPI - Version](https://img.shields.io/pypi/v/qwikcrud.svg)](https://pypi.org/project/qwikcrud)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/qwikcrud.svg)](https://pypi.org/project/qwikcrud)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install qwikcrud
```

## License

`qwikcrud` is distributed under the terms of the [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html) license.